def 网页协议_响应文本_取右边(响应文本, 目标文本):
    """
    获取响应的文本内容，并从中找到目标文本右边的部分。

    参数:
        - 响应文本 (str): 服务器响应的文本内容。
        - 目标文本 (str): 目标文本，函数将返回位于目标文本右边的部分。

    返回:
        - str: 目标文本右边的部分文本。如果响应为 None、未找到目标文本、或出现任何异常，则返回空字符串。
    """
    try:
        if 响应文本 is not None:
            目标位置 = 响应文本.find(目标文本)
            if 目标位置 != -1:
                目标位置 += len(目标文本)
                右边文本 = 响应文本[目标位置:]
                return 右边文本
            return ''
        else:
            return ''
    except Exception:
        return ''