def 算数_求余数(被除数, 除数):
    """
    计算被除数除以除数的余数。

    参数:
        被除数 (int): 被除数。
        除数 (int): 除数。

    返回:
        int: 余数。

    使用示例:
        print(算数_求余数(10, 3))  # 输出：1
        print(算数_求余数(7, 4))   # 输出：3
    """
    return 被除数 % 除数
